# Component Implementation: {Component Name}

## Architecture Reference
→ `/architecture/releases/{release}/components/{component}.md`

## Implementation Goal
{Конкретная цель компонента - что делает, какую проблему решает}

## Epics Overview

### Epic-01: {Epic Name}
**Status:** planned
**Outcome:** {Что будет работать после эпика}

### Epic-02: {Epic Name}  
**Status:** planned
**Outcome:** {Что будет работать после эпика}

## Dependencies
- {Внешняя зависимость или другой компонент}
- {Инфраструктурное требование}

## Tech Notes
{Ссылка на system-patterns.md если применимы общие паттерны}
{Специфичные для компонента особенности}